/*
 *  complex.cpp
 *
 *  Author: M. Reza Mozaffari
 *  Physics Group, University of Qom
 *  Created on: Jan. 2021
 */

#include "complex.h"

complex::complex()
{
    x = 0.0;
    y = 0.0;
}

complex::complex(double _x, double _y)
{
    x = _x;
    y = _y;
}

void complex::print()
{
    printf("(%.6f, %.6f)\n", x, y);
}

double complex::get_real()
{
    return x;
}

double complex::get_imag()
{
    return y;
}

void complex::set_real(double _x)
{
    x = _x;
}

void complex::set_imag(double _y)
{
    y = _y;
}

complex complex::operator=(complex z)
{
    x = z.get_real();
    y = z.get_imag();

    return *this;
}

complex complex::conj()
{
    complex tmp;
    tmp.set_real(x);
    tmp.set_imag(-y);

    return tmp;
}

double complex::norm()
{
    return sqrt(x * x + y * y);
}

double complex::arg()
{
    return atan2(y, x);
}

complex complex::power(int n)
{
    double r {0.0}, theta {0.0};
    r = norm();
    theta = arg();
    
    complex tmp;
    tmp.set_real(pow(r, n)*cos(n*theta));
    tmp.set_imag(pow(r, n)*sin(n*theta));
    
    return tmp;
}
void print(complex z)
{
    printf("(%.6f, %.6f)\n", z.get_real(), z.get_imag());
}

complex conj(complex z)
{
    complex tmp;
    tmp.set_real(z.get_real());
    tmp.set_imag(-z.get_imag());

    return tmp;
}

double norm(complex z)
{
    double x{ 0.0 }, y{ 0.0 };
    x = z.get_real();
    y = z.get_imag();

    return sqrt(x * x + y * y);
}

double arg(complex z)
{
    double x{ 0.0 }, y{ 0.0 };
    x = z.get_real();
    y = z.get_imag();

    return atan2(y, x);
}